@@ -3,11 +3,19 @@
 from deepr.layers.base import Layer, layer
 from deepr.layers.bpr import BPR, MaskedBPR
 from deepr.layers.click_rank import ClickRank
-from deepr.layers.combinators import Sequential, Select, Rename, Parallel
-from deepr.layers.core import Product, Sum, Concat, Dense, LogicalAnd, DotProduct, Add, Identity, Conv1d
+from deepr.layers.combinators import Sequential, Select, Rename, Parallel, ActiveMode
+from deepr.layers.core import Product, Sum, Concat, Dense, LogicalAnd, DotProduct, Add, Identity, Conv1d, ToFloat
 from deepr.layers.dropout import SpatialDropout1D, Dropout
 from deepr.layers.embedding import Embedding, CombineEmbeddings
-from deepr.layers.lookup import Lookup, LookupFromFile, LookupFromMapping, table_from_file, table_from_mapping
+from deepr.layers.lookup import (
+    Lookup,
+    LookupFromFile,
+    LookupFromMapping,
+    LookupIndexToString,
+    index_to_string_table_from_file,
+    table_from_file,
+    table_from_mapping,
+)
 from deepr.layers.mask import Equal, NotEqual, BooleanMask, BooleanReduceMode, LookAheadMask, PaddingMask
 from deepr.layers.reduce import Average, WeightedAverage
 from deepr.layers.size import IsMinSize
